%define _default_patch_fuzz 2

# compile against kerberos
%define enable_krb5	0
%{?_with_kerberos: %global enable_krb5 1}

# enable sasl2
# note that sasl2 includes kerberos support via sasl
%define enable_sasl2	1

%global __requires_exclude perl\\(timelocal.pl\\)

Name:		mutt
Epoch:		1
Version:	1.10.1
%define subrel 1
Release:	%mkrel 1
Summary:	Text mode mail user agent
License:	GPL
Group:		Networking/Mail
Url:		http://www.mutt.org/
Source0:	https://bitbucket.org/mutt/mutt/downloads/%{name}-%{version}.tar.gz
Source1:	https://bitbucket.org/mutt/mutt/downloads/%{name}-%{version}.tar.gz.asc

#
# NOTE: For any patch that modifies Muttrc, please modify Muttrc.head.in
# instead, because Muttrc is automatically generated, so any change will
# be lost
#

#
# Patch 1-99: Mandriva patches
#

# Set tmpdir to ~/tmp in sample config
Patch1:		%{name}-1.3.15-tmpdef.patch

# Tell user to install urlview instead of just barf at user
Patch2:         %{name}-1.5.18-urlview.patch

# Allow non root users to install mutt
Patch3:		%{name}-1.5.24-no-sgid.patch

# Don't include /usr/include/ncurses if not building against normal ncurses
Patch4:		%{name}-1.5.5.1-ncurses-include.patch

# fixes the viewing of MIME attached files when the mailcap
# entry already uses quotes (eg: "%s")
Patch5:		mutt-1.5.11-mailcap.patch

# defines gpg paths, aspell, and fallback charsets
Patch6:		mutt-1.5.20-gpg.patch

#
# Patch 100- : external patches
#

# NNTP support
# http://www.mutt.org.ua/download/mutt-%{version}/patch-%{version}.vvv.nntp.gz
Patch101:	https://www.mutt.org.ua/download/mutt-1.10.0/patch-1.10.0.vvv.nntp.gz
#Patch101:       https://www.mutt.org.ua/download/mutt-%{version}/patch-%{version}.vvv.nntp.gz

# Dynamically set xterm window title / icon name
Patch108:	%{name}-1.9.1-xterm-title.patch

BuildRequires:	bzip2-devel
BuildRequires:	linuxdoc-tools
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(ncursesw)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	sendmail-command
BuildRequires:	db-devel >= 5.3
BuildRequires:	gpgme-devel

# manual generation
BuildRequires:	xsltproc
BuildRequires:	docbook-style-xsl
# html manual -> txt manual conversion (lynx messes up the encoding)
BuildRequires:	w3m

%if %enable_krb5
BuildRequires:	krb5-devel
%endif

%if %enable_sasl2
BuildRequires:	pkgconfig(libsasl2) >= 2.1
Requires:	sasl-plug-login
%endif

# without it we have problems with attachments (e.g. .pdfs)
Recommends: mailcap
Recommends: mutt-doc
Recommends: mutt-utf8


%description
Mutt is a text mode mail user agent. Mutt supports color, threading,
arbitrary key remapping, and a lot of customization.

You should install mutt if you've used mutt in the past and you prefer
it, or if you're new to mail programs and you haven't decided which
one you're going to use.

%package	utf8
Summary:	Text mode mail user agent supporting wide character
Group:		Networking/Mail
Requires:	%{name} = %{epoch}:%{version}-%{release}

%description	utf8
Mutt is a text mode mail user agent. Mutt supports color, threading,
arbitrary key remapping, and a lot of customization.

You should install mutt if you've used mutt in the past and you prefer
it, or if you're new to mail programs and you haven't decided which
one you're going to use.

NOTE: This version of mutt is linked against ncurses with wide char
      support, and is useful for, say, people using UTF-8 locales.

%package	doc
Summary:	Manual for Mutt, a text mode mail user agent
Group:		Networking/Mail

%description	doc
This is the complete manual for Mutt, in text and HTML formats.

Mutt is a text mode mail user agent. Mutt supports color, threading,
arbitrary key remapping, and a lot of customization.

You should install mutt if you've used mutt in the past and you prefer
it, or if you're new to mail programs and you haven't decided which
one you're going to use.


%prep
%setup -q
%patch1 -p1 -b .tmpdef
%patch2 -p1 -b .urlview
%patch3 -p0 -b .no-sgid
#patch4 -p1 -b .no-ncurses-normal
%patch5 -p1 -b .mailcap
%patch6 -p0 -b .gpg
%patch101 -p1 -b .nntp
%patch108 -p1 -b .xterm-title

# Fix some bad references in the man pages
# Reference to imapd is not fixed, since uw-imap/courier/cyrus all have
# different paths
perl -pi -e 's|/usr/local/bin|%{_bindir}|g; s|/usr/local/doc/mutt|%{_docdir}/%{name}-doc|g;' doc/*.man init.h

%build

# needed by nntp patch
autoreconf -fi

build()
{
	CONFIGURE_TOP=.. %configure2_5x \
	--with-docdir=%{_docdir}/%{name}-doc \
	--enable-smtp		\
	--enable-pop		\
	--enable-imap		\
	--enable-nfs-fix	\
	--with-ssl		\
	--enable-compressed	\
	--enable-hcache		\
	--without-gdbm		\
	--with-bdb		\
	--enable-pgp		\
	--enable-smime		\
	--enable-gpgme		\
%if %enable_krb5
	--with-gss 		\
%else
	--without-gss 		\
%endif
%if %enable_sasl2
	--with-sasl 		\
%else
	--without-sasl	 	\
%endif
	--enable-nntp		\
	--enable-sidebar	\
	$@

	# no parallel make
	%__make -j4
}

# build normal version
### ugly. ugly.
perl -pi -e 's/ncurses ncursesw/ncurses # ncursesw/' configure
mkdir mutt-normal
pushd mutt-normal
CPPFLAGS=-DNCURSES_WIDECHAR=0 build
popd

# build another version enabling wide char support
### ugly. ugly.
perl -pi -e 's/ncurses # ncursesw/ncursesw # ncurses/' configure
mkdir mutt-utf-8
pushd mutt-utf-8
build

# "make install" installs $builddir/Muttrc into $buildroot
make update-doc
#mv -f Muttrc ../Muttrc

popd

%install
pushd mutt-utf-8
%make_install
mv %{buildroot}%{_bindir}/mutt %{buildroot}%{_bindir}/mutt-utf8
popd

pushd mutt-normal
install -m 755 mutt %{buildroot}%{_bindir}/mutt-normal
popd

# get rid of unpackaged files
rm -f %{buildroot}%{_sysconfdir}/mime.types
mv -f %{buildroot}%{_sysconfdir}/mime.types.dist .
mv -f %{buildroot}%{_sysconfdir}/Muttrc.dist .

%find_lang %{name}

%post
update-alternatives --install %{_bindir}/mutt mutt %{_bindir}/mutt-normal 10

%preun
if [ $1 -eq 0 ]; then
  update-alternatives --remove mutt %{_bindir}/mutt-normal
fi

%post utf8
update-alternatives --install %{_bindir}/mutt mutt %{_bindir}/mutt-utf8 20

%preun utf8
if [ $1 -eq 0 ]; then
  update-alternatives --remove mutt %{_bindir}/mutt-utf8
fi

%triggerpostun -- %{name} < %{epoch}:1.5
update-alternatives --install %{_bindir}/mutt mutt %{_bindir}/mutt-normal 10

%files -f %{name}.lang
%doc BEWARE COPYRIGHT NEWS OPS* PATCHES*
%doc README* TODO UPDATING VERSION
%doc mime.types.dist Muttrc.dist
%doc contrib/sample.muttrc*
%config(noreplace) %{_sysconfdir}/Muttrc
%{_mandir}/man?/*
%{_bindir}/flea
%{_bindir}/mutt-normal
%{_bindir}/muttbug
%{_bindir}/pgpewrap
%{_bindir}/pgpring
%{_bindir}/smime_keys
%attr(2755, root, mail) %{_bindir}/mutt_dotlock

%files utf8
%{_bindir}/mutt-utf8

%files doc
%doc %{_docdir}/%{name}-doc/


%changelog
* Thu Oct 11 2018 bcornec <bcornec> 1:1.10.1-1.1.mga6
+ Revision: 1319447
- Update to upstream mutt 1.10.1 to fix mga#23345

* Sun Jan 29 2017 daviddavid <daviddavid> 1:1.7.2-3.mga6
+ Revision: 1083985
- fix manual file generation and conversion (mga#17017)

* Sun Jan 29 2017 wally <wally> 1:1.7.2-2.mga6
+ Revision: 1083921
- enable sidebar support again (mga#20199)

* Thu Dec 29 2016 daviddavid <daviddavid> 1:1.7.2-1.mga6
+ Revision: 1078633
- new version: 1.7.2 (fixes build against GPGME 1.8)
- update compressed-mbox and vvv.nntp patches

* Thu Sep 22 2016 wally <wally> 1:1.7.0-3.mga6
+ Revision: 1055160
- require sasl-plug-login to allow smtps logins (mga#19436)

* Thu Sep 15 2016 wally <wally> 1:1.7.0-2.mga6
+ Revision: 1053079
- enable idn support
- properly enable gpgme support

* Sun Sep 11 2016 luigiwalser <luigiwalser> 1:1.7.0-1.mga6
+ Revision: 1051556
- fix release tag

* Sun Sep 11 2016 luigiwalser <luigiwalser> 1:1.7.0-0.mga6
+ Revision: 1051526
- 1.7.0
- changes thanks to Theodoros Kalamatianos:
  - remove patch 7 (fixed upstream)
  - update patches 100 and 101

* Wed Mar 02 2016 umeabot <umeabot> 1:1.5.24-3.mga6
+ Revision: 983780
- Rebuild for openssl

* Mon Feb 15 2016 umeabot <umeabot> 1:1.5.24-2.mga6
+ Revision: 961532
- Mageia 6 Mass Rebuild

* Tue Oct 27 2015 bcornec <bcornec> 1:1.5.24-1.mga6
+ Revision: 895793
- Update mutt to upstream 1.5.24 (fixes a very annoying bug on multilines To:/Cc: headers which weren't displayed anymore). Had to disable index-color and siebar for now as they are not working correctly with 1.5.24. Will work on this later on.

* Sun Oct 25 2015 daviddavid <daviddavid> 1:1.5.23-2.mga6
+ Revision: 895261
- fix doc from mutt-doc subpackage

* Wed Dec 03 2014 luigiwalser <luigiwalser> 1:1.5.23-1.mga5
+ Revision: 800511
- 1.5.23
- use working source URLs
- changes thanks to Theodoros Kalamatianos:
  - rediff patches 3, 7, 100, 101, 104, 108 and 109 (some from debian)
  - remove upstreamed patches 110, 111, and 112
  - update to 1.5.23 CVE-2014-9116 patch from debian
  - build non-utf8 and utf8 ncurses builds correctly

* Mon Dec 01 2014 luigiwalser <luigiwalser> 1:1.5.21-16.mga5
+ Revision: 800245
- add patch from debian to fix CVE-2014-9116

* Wed Oct 15 2014 umeabot <umeabot> 1:1.5.21-15.mga5
+ Revision: 745112
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:1.5.21-14.mga5
+ Revision: 682707
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
- s/uggests:/Recommends:/

* Tue Mar 18 2014 oden <oden> 1:1.5.21-13.mga5
+ Revision: 604887
- P112: security fix for CVE-2014-0467 (rhel6)

* Sat Oct 19 2013 umeabot <umeabot> 1:1.5.21-12.mga4
+ Revision: 533221
- Mageia 4 Mass Rebuild

* Tue Aug 27 2013 luigiwalser <luigiwalser> 1:1.5.21-11.mga4
+ Revision: 472081
- rebuild for cyrus-sasl

* Mon Aug 05 2013 fwang <fwang> 1:1.5.21-10.mga4
+ Revision: 463740
- cleanup spec

* Sun Jan 13 2013 luigiwalser <luigiwalser> 1:1.5.21-10.mga3
+ Revision: 362926
- fix for automake 1.13
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ fwang <fwang>
- recognize db 5.3

* Tue Jul 31 2012 fwang <fwang> 1:1.5.21-8.mga3
+ Revision: 276331
- rebuild for db-5.3

* Fri Jul 27 2012 fwang <fwang> 1:1.5.21-7.mga3
+ Revision: 274789
- drop obosleted macros
- build with db5

* Tue Apr 03 2012 jquelin <jquelin> 1:1.5.21-6.mga2
+ Revision: 228179
- fix cve-2011-1429 (mga#5203)

* Mon Jan 02 2012 jquelin <jquelin> 1:1.5.21-5.mga2
+ Revision: 189610
- suggesting mutt-doc now that f1 points to mutt-doc

* Sat Dec 24 2011 jquelin <jquelin> 1:1.5.21-4.mga2
+ Revision: 187228
- updating real path to doc directory (mga#3869)

* Sat Dec 24 2011 jquelin <jquelin> 1:1.5.21-3.mga2
+ Revision: 187172
- updating real path to doc directory (mga#3869)

* Fri Apr 01 2011 shikamaru <shikamaru> 1:1.5.21-3.mga1
+ Revision: 79544
- Fix sidebar: readd sidebar_sort

* Sun Jan 09 2011 shikamaru <shikamaru> 1:1.5.21-2.mga1
+ Revision: 2315
- imported package mutt


* Thu Dec 23 2010 Lev Givon <lev@mandriva.org> 1:1.5.21-2mdv2011.0
+ Revision: 624136
- Fix misaligned Security line on composition screen.

* Sun Oct 31 2010 Rémy Clouard <shikamaru@mandriva.org> 1:1.5.21-1mdv2011.0
+ Revision: 590961
- Bump to 1.5.21
- apply sidebar patch from http://spacehopper.org/mutt/sidebar-5302767aa6aa.gz
  (thanks lev for the tip)
- rediff most patches (see below for the touchy ones)
- comment out patch107 (merged upstream, peer review would be appreciated)
- nntp patch rediffed (peer review please ? :) )

* Mon Apr 05 2010 Eugeni Dodonov <eugeni@mandriva.com> 1:1.5.20-8mdv2010.1
+ Revision: 531864
- P7: properly handle subjectAltNames under openssl-1.0.0.

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 1:1.5.20-7mdv2010.1
+ Revision: 511592
- rebuilt against openssl-0.9.8m

* Mon Jan 25 2010 Rémy Clouard <shikamaru@mandriva.org> 1:1.5.20-6mdv2010.1
+ Revision: 496291
- add mutt-utf8 as a suggests

* Wed Jan 06 2010 Rémy Clouard <shikamaru@mandriva.org> 1:1.5.20-5mdv2010.1
+ Revision: 486870
- fix a bug where hilighted line in the index was wrongly redrawn

* Sun Jan 03 2010 Rémy Clouard <shikamaru@mandriva.org> 1:1.5.20-4mdv2010.1
+ Revision: 485893
- add patch from previous commit
- add indexcolor patch

* Fri Jan 01 2010 Oden Eriksson <oeriksson@mandriva.com> 1:1.5.20-3mdv2010.1
+ Revision: 484725
- rebuilt against bdb 4.8

* Thu Oct 08 2009 Eugeni Dodonov <eugeni@mandriva.com> 1:1.5.20-2mdv2010.0
+ Revision: 455940
- Updated to new sidebar patch.

* Wed Sep 23 2009 Jérôme Quelin <jquelin@mandriva.org> 1:1.5.20-1mdv2010.0
+ Revision: 447815
- oops, should reset rel
- update to 1.5.20
- updated manually gpg patch (don't we have an upstream url?
- updated vvv and rr.compressed patches with their upstream version
- removed sidebar patch which is not maintained upstream, doesn't apply
  cleanly, and is not really useful (i was the original requester for
  its inclusion)

* Wed Sep 23 2009 Oden Eriksson <oeriksson@mandriva.com> 1:1.5.19-2mdv2010.0
+ Revision: 447772
- P106: security fix for CVE-2009-1390 (redhat)
- P107: security fix for nul cert spoof

* Tue Jun 16 2009 Lev Givon <lev@mandriva.org> 1:1.5.19-1mdv2010.0
+ Revision: 386370
- Update to 1.5.19.
  Update included external patches (nntp, compression, sidebar).

* Mon Dec 15 2008 Oden Eriksson <oeriksson@mandriva.com> 1:1.5.18-2mdv2009.1
+ Revision: 314512
- rediffed fuzzy patches
- rebuilt against db4.7

* Sun Jul 06 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 1:1.5.18-1mdv2009.0
+ Revision: 232031
- Updated to version 1.5.18
- Rediffed urlview patch.
- Added updated versions of included external patches (compressed folder
  support, NNTP support and Sidebar support).

* Thu Jan 24 2008 Ademar de Souza Reis Jr <ademar@mandriva.com.br> 1:1.5.17-5mdv2008.1
+ Revision: 157701
- add mailcap as suggestion (w/out it, .pdfs are attached as
  text/plain and get scrambled)

* Thu Jan 03 2008 Jérôme Quelin <jquelin@mandriva.org> 1:1.5.17-4mdv2008.1
+ Revision: 142102
- adding sidebar support (fixing bug 29371)

* Thu Dec 27 2007 Oden Eriksson <oeriksson@mandriva.com> 1:1.5.17-3mdv2008.1
+ Revision: 138191
- rebuilt against bdb 4.6.x libs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Nov 12 2007 Andreas Hasenack <andreas@mandriva.com> 1:1.5.17-2mdv2008.1
+ Revision: 108133
- rebuild to get correct permissions on manpages (lzma bug)

* Mon Nov 05 2007 Andreas Hasenack <andreas@mandriva.com> 1:1.5.17-1mdv2008.1
+ Revision: 106022
- updated to version 1.5.17

  + Thierry Vignaud <tv@mandriva.org>
    - s/mandrake/mandriva/

* Fri Sep 21 2007 Andreas Hasenack <andreas@mandriva.com> 1:1.5.16-4mdv2008.0
+ Revision: 92110
- mutt doesn't need an external MTA anymore: it has builtin smtp support now

* Mon Sep 17 2007 Andreas Hasenack <andreas@mandriva.com> 1:1.5.16-3mdv2008.0
+ Revision: 89320
- drop CVE-2006-5298 patch, it was already fixed upstream in a different way (#29916)

* Wed Jun 27 2007 Andreas Hasenack <andreas@mandriva.com> 1:1.5.16-2mdv2008.0
+ Revision: 45052
- rebuild with new rpm-mandriva-setup (-fstack-protector)

* Thu Jun 21 2007 Andreas Hasenack <andreas@mandriva.com> 1:1.5.16-1mdv2008.0
+ Revision: 42310
- updated to version 1.5.16
- fixed doc dir according to new policy
- dropped CVE-2007-2683 security patch, already applied
- redid/updated urlview, nntp and compressed patches
- added security fix for CVE-2007-2683 (Closes: #31191)

* Wed May 16 2007 Gustavo De Nardin <gustavodn@mandriva.com> 1:1.5.15-4mdv2008.0
+ Revision: 27316
- renamed just introduced mutt-manual subpackage to mutt-doc (no Obsoletes)

* Wed May 16 2007 Gustavo De Nardin <gustavodn@mandriva.com> 1:1.5.15-3mdv2008.0
+ Revision: 27137
- introduce mutt-manual subpackage, with the full manual for Mutt

* Wed May 02 2007 Andreas Hasenack <andreas@mandriva.com> 1:1.5.15-2mdv2008.0
+ Revision: 20595
- disabled parallel make, doesn't work
- forgot to enable smtp support
- updated to version 1.5.15 (smtp support \o/)
- updated patches for this version


* Fri Mar 02 2007 Andreas Hasenack <andreas@mandriva.com> 1.5.14-1mdv2007.0
+ Revision: 131589
- updated to version 1.5.14
- removed CVE-2006-5297 patch, already applied
- updated external patches

* Wed Nov 29 2006 Andreas Hasenack <andreas@mandriva.com> 1:1.5.13-1mdv2007.1
+ Revision: 88789
- updated to version 1.5.13
- updated many patches

* Mon Oct 30 2006 Andreas Hasenack <andreas@mandriva.com> 1:1.5.11-6mdv2007.1
+ Revision: 73825
- added patches for CVE-2006-5297 and CVE-2006-5298
  (#26787)
- rebuild with new ncurses (5.5-1.20051029.3mdv2007.0)
- reverted back to 1.5.11: 1.5.12 as it was committed doesn't build
  and we are in freeze anyway

  + Jérôme Soyer <saispo@mandriva.org>
    - Remove patch105
    - New release 1.5.12

* Sat Jul 01 2006 Andreas Hasenack <andreas@mandriva.com> 1:1.5.11-4mdv2007.0
+ Revision: 38203
- bunzipped the remaining patches
- added security patch for CVE-2006-3242 (#23424)
- import mutt-1.5.11-3mdv2007.0

* Wed May 31 2006 Pablo Saratxaga <pablo@mandriva.com> 1.5.11-3mdk
- use aspell instead of ispell
- set paths to gpg, so it works out of the box (if gpg installed)
- corrected bug when calling external programs to view attached files

* Sun Nov 13 2005 Oden Eriksson <oeriksson@mandriva.com> 1.5.11-2mdk
- rebuilt against openssl-0.9.8a

* Sat Oct 01 2005 Andreas Hasenack <andreas@mandriva.com> 1.5.10i-1mdk
- updated to version 1.5.11 (no "i" from now on)
- removed thread patch, already applied
- updated nntp patch
- updated compressed folders patch

* Wed Aug 31 2005 Frederic Lepied <flepied@mandriva.com> 1.5.9i-9mdk
- removed BuildRequires on ispell as it's not in main anymore

* Wed Jul 27 2005 Nicolas Lécureuil <neoclust@mandriva.org> 1.5.9i-8mdk
- Fix smtpdaemon on BuildRequire
- %% mkrel

* Tue Jul 12 2005 Andreas Hasenack <andreas@mandriva.com> 1.5.9i-7mdk
- changed Requires from smtpdaemon to sendmail-command

* Tue Apr 26 2005 Andreas Hasenack <andreas@mandrivalinux.com> 1.5.9i-6mdk
- updated to version 1.5.9i
- removed P5, it's already fixed in this version
- updated compressed folder patch for this version
- updated nntp patch for this version
- removed hcache patch, the imap part is already applied and is actually
  the more important one (maildir is already fast)
- redid edit-threads patch for this version
- updated save_history patch to version 1.5.6 (latest available at this time)
- using current autoconf/automake now as it is compatible with the new nntp
  patch version

* Wed Mar 30 2005 Andreas Hasenack <andreas@mandrakesoft.com> 1.5.6i-5mdk
- just a rebuild and a release increase, since the last package never went
  into cooker

* Sun Mar 13 2005 Andreas Hasenack <andreas@mandrakesoft.com> 1.5.6i-4mdk
- added conditional sasl2 build (enabled by default) (Closes: #14221)
- added configure options to honor kerberos build which was previously
  only relying on a buildrequires
- since mutt is built twice, use a shell function instead of calling
  configure/make "inline"
- added header cache patch with the Makefile.am hunk slightly modified
  because of the nntp patch
- added libdb4.2-devel buildrequires because of the header_cache patch.
  This patch can use either BDB or GDBM: I prefer BDB.
- added P5 to fix #13020

* Wed Jan 12 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.5.6i-3mdk
- fix buildrequires

* Wed Jun 02 2004 Marcel Pol <mpol@mandrake.org> 1.5.6i-2mdk
- buildrequires autoconf2.1 (slbd)

* Sat Apr 17 2004 Abel Cheung <deaddog@deaddog.org> 1.5.6i-1mdk
- New version
- Regen patches

